summaryrefslogtreecommitdiffabout
path: root/libkdepim/externalapphandler.h
Side-by-side diff
Diffstat (limited to 'libkdepim/externalapphandler.h') (more/less context) (ignore whitespace changes)
-rw-r--r--libkdepim/externalapphandler.h18
1 files changed, 12 insertions, 6 deletions
diff --git a/libkdepim/externalapphandler.h b/libkdepim/externalapphandler.h
index efcdd89..3cf9e06 100644
--- a/libkdepim/externalapphandler.h
+++ b/libkdepim/externalapphandler.h
@@ -81,11 +81,17 @@ class ExternalAppHandler
AVAILABLE = 1
};
- //calls the emailapplication with a number of attachments that need to be send
- bool mailAttachments( const QString& urls );
+ //calls the emailapplication with a number of attachments that need to be send.
+ //either parameter can be left empty.
+ bool mailToMultipleContacts( const QString& recipients, const QString& attachmenturls );
- //calls the emailapplication and creates a mail with parameter emails as recipients
- bool mailToContacts( const QString& emails );
+ //calls the emailapplication and creates a mail with parameter emailadress as recipients
+ bool mailToOneContact( const QString& name, const QString& emailadress );
+
+ //calls the emailapplication and creates a mail with parameter as recipients
+ // parameters format is
+ // NAME <EMAIL>:SUBJECT
+ bool mailToOneContact( const QString& adressline );
//calls the phoneapplication with the number
bool callByPhone( const QString& phonenumber );
@@ -127,8 +133,8 @@ class ExternalAppHandler
void addDefaultAppItem(Types type, int id, const QString& label, const QString& channel, const QString& message, const QString& parameters, const QString& message2, const QString& parameters2);
- QString& translateMessage(QString& message, const QString& emails) const;
- void passParameter(QCopEnvelope* e, const QString& parameters, const QString& param1) const;
+ QString& translateMessage(QString& message, const QString& param1, const QString& param2) const;
+ void passParameters(QCopEnvelope* e, const QString& parameters, const QString& param1, const QString& param2) const;
static ExternalAppHandler *sInstance;